summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGMaskElementImpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksvg/impl/SVGMaskElementImpl.h')
-rw-r--r--ksvg/impl/SVGMaskElementImpl.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/ksvg/impl/SVGMaskElementImpl.h b/ksvg/impl/SVGMaskElementImpl.h
index 2a96967c..4631ebae 100644
--- a/ksvg/impl/SVGMaskElementImpl.h
+++ b/ksvg/impl/SVGMaskElementImpl.h
@@ -56,7 +56,7 @@ public:
{
public:
Mask() : m_width(0), m_height(0) {}
- Mask(const TQByteArray& mask, const TQWMatrix& screenToMask, int width, int height);
+ Mask(const TQByteArray& tqmask, const TQWMatrix& screenToMask, int width, int height);
~Mask() {}
bool isEmpty() const { return m_width == 0; }
@@ -68,15 +68,15 @@ public:
private:
int m_width;
int m_height;
- TQByteArray m_mask;
+ TQByteArray m_tqmask;
TQWMatrix m_screenToMask;
};
SVGMaskElementImpl(DOM::ElementImpl *);
virtual ~SVGMaskElementImpl();
- SVGAnimatedEnumerationImpl *maskUnits() const;
- SVGAnimatedEnumerationImpl *maskContentUnits() const;
+ SVGAnimatedEnumerationImpl *tqmaskUnits() const;
+ SVGAnimatedEnumerationImpl *tqmaskContentUnits() const;
SVGAnimatedLengthImpl *x() const;
SVGAnimatedLengthImpl *y() const;
SVGAnimatedLengthImpl *width() const;
@@ -89,10 +89,10 @@ public:
Mask createMask(SVGShapeImpl *referencingElement);
- // Compute the mask on a given shape, taking into account all masks defined
- // on the shape's ancestors. This is a workaround for us not having a buffer
- // for container elements, so we can't mask containers directly.
- static TQByteArray maskRectangle(SVGShapeImpl *shape, const TQRect& screenRectangle);
+ // Compute the tqmask on a given tqshape, taking into account all tqmasks defined
+ // on the tqshape's ancestors. This is a workaround for us not having a buffer
+ // for container elements, so we can't tqmask containers directly.
+ static TQByteArray tqmaskRectangle(SVGShapeImpl *tqshape, const TQRect& screenRectangle);
private:
class CacheKey
@@ -110,8 +110,8 @@ private:
Mask createMask(SVGShapeImpl *referencingElement, int imageWidth, int imageHeight);
- SVGAnimatedEnumerationImpl *m_maskUnits;
- SVGAnimatedEnumerationImpl *m_maskContentUnits;
+ SVGAnimatedEnumerationImpl *m_tqmaskUnits;
+ SVGAnimatedEnumerationImpl *m_tqmaskContentUnits;
SVGAnimatedLengthImpl *m_x;
SVGAnimatedLengthImpl *m_y;
SVGAnimatedLengthImpl *m_width;
@@ -120,7 +120,7 @@ private:
SVGUnitConverter *m_converter;
KSVGCanvas *m_canvas;
- MinOneLRUCache<CacheKey, Mask> m_maskCache;
+ MinOneLRUCache<CacheKey, Mask> m_tqmaskCache;
public:
KSVG_GET
@@ -137,7 +137,7 @@ public:
void putValueProperty(KJS::ExecState *exec, int token, const KJS::Value &value, int attr);
};
-KSVG_REGISTER_ELEMENT(SVGMaskElementImpl, "mask")
+KSVG_REGISTER_ELEMENT(SVGMaskElementImpl, "tqmask")
inline unsigned char SVGMaskElementImpl::Mask::value(int screenX, int screenY) const
{
@@ -146,7 +146,7 @@ inline unsigned char SVGMaskElementImpl::Mask::value(int screenX, int screenY) c
m_screenToMask.map(screenX, screenY, &x, &y);
if(x >= 0 && x < m_width && y >= 0 && y < m_height)
- return m_mask[x + y * m_width];
+ return m_tqmask[x + y * m_width];
else
return 0;
}